Spyral is a library/engine for developing 2D games in Python, with a focus in rapid development and clean designs.

Currently, spyral's main source of documentation comes from docstrings in the source code. Some additional documentation and examples can be found at the Platipy project, which documents Spyral in the context of a university course for which it was developed.

`Visit the Platipy Project <http://platipy.readthedocs.org>`_